==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/modifica_prenota.php <==
<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Modify or delete reservation"; break;
case "Prenotazione a nome di":  		$messaggio = "Reservation for"; break;
case "nato il":  				$messaggio = "born the"; break;
case "nata il":  				$messaggio = "born the"; break;
case "e":  					$messaggio = "and"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "2 telefono":  				$messaggio = "2nd telephone"; break;
case "3 telefono":  				$messaggio = "3rd telephone"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify client's data"; break;
case "La prenotazione  dell'anno precedente, si potr modificare solo la data finale":	$messaggio = "The reservation is from previus year, you will be able to modify only the final date"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "cambia in":  				$messaggio = "change to"; break;
case "Appartamento":  				$messaggio = "Apartment"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "mobile":  				$messaggio = "mobile"; break;
case "in":  					$messaggio = "in"; break;
case "Cambia metodo per l'assegnazione dell'appartamento":	$messaggio = "Change the method for the apartment assignation"; break;
case "N fisso di appartamento":  		$messaggio = "Fixed apartment No"; break;
case "Mobile in tutti gli appartamenti":  	$messaggio = "Mobile in all the apartments"; break;
case "Lista di appartamenti":  			$messaggio = "Apartments list"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "N di piano":  				$messaggio = "Floor number"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "N di persone":  				$messaggio = "Number of people"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Cancella il commento":  			$messaggio = "Delete comment"; break;
case "Tipo di tariffa":  			$messaggio = "Fare type"; break;
case "riassegna l'appartamento con la regola 2":	$messaggio = "reassign the apartment with rule 2"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Sconto":  				$messaggio = "Discount"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "resto":  					$messaggio = "rest"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Calculate again the deposit from the new fare"; break;
case "Costo aggiuntivo finale":  		$messaggio = "Single extra cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Weekly extra cost"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Daily extra cost"; break;
case "per":  					$messaggio = "for"; break;
case "settimane moltiplicato per":  		$messaggio = "weeks multiplied by"; break;
case "giorni moltiplicato per":  		$messaggio = "days multiplied by"; break;
case "Costo aggiuntivo percentuale":  		$messaggio = "Percentage extra cost"; break;
case "della tariffa moltiplicato per":  	$messaggio = "of the fare multiplied by"; break;
case "Prenotazione confermata":  		$messaggio = "Reservation confirmed"; break;
case "Totale da pagare":  			$messaggio = "Total to be paid"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "pagato tutto":  				$messaggio = "all paid"; break;
case "caparra ":  				$messaggio = "deposit paid"; break;
case "Ancora da pagare":  			$messaggio = "Still to be paid"; break;
case "Nuovo costo aggiuntivo finale":  		$messaggio = "New single extra cost"; break;
case "di":  					$messaggio = "of"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "letto":  					$messaggio = "bed"; break;
case "straordinario":  				$messaggio = "extraordinary"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "New weekly extra cost"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "New daily extra cost"; break;
case "n di settimane da applicare":  		$messaggio = "number of weeks to apply"; break;
case "n di giorni da applicare":  		$messaggio = "number of days to apply"; break;
case "Nuovo costo aggiuntivo percentuale":  	$messaggio = "New percentage extra cost"; break;
case "non specificato":  			$messaggio = "not available"; break;
case "Modifica la prenotazione":  		$messaggio = "Modify reservation"; break;
case "Cancella la prenotazione":  		$messaggio = "Delete reservation"; break;
case "Visualizza il contratto":  		$messaggio = "View contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "SI":  					$messaggio = "YES"; break;
case "cancella anche ci che era stato pagato":	$messaggio = "delete also what was paid"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  			$messaggio = "Reservation"; break;
case "era gi stata cancellata":  		$messaggio = "has already been deleted"; break;
case "Prenotazione":  				$messaggio = "Reservation"; break;
case "cancellata":  				$messaggio = "deleted"; break;
case "<b>non  stata cancellata</b> perch  stata modificata nel frattempo":	$messaggio = "<b>has not been deleted</b> because has been modified meanwhile"; break;
case "Si  sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Are you sure you want to <b>delete</b> reservation"; break;
case "La data iniziale verr cambiata dal":  	$messaggio = "The beginning date will be changed from"; break;
case "al":  					$messaggio = "to"; break;
case "La data finale verr cambiata dal":  	$messaggio = "The final date will be changed from"; break;
case "Le <font color=\"red\">date</font> sono <b>sbagliate</b>":	$messaggio = "The <font color=\"red\">dates</font> are <b>wrong</b>"; break;
case "La prenotazione verr spostata dall'appartamanto":	$messaggio = "The reservation will be moved from apartment"; break;
case "L'assegnazione dell'appartamento verr cambiata dal":	$messaggio = "The apartment assignation will be changed from"; break;
case "ad uno tra":  				$messaggio = "to an apartment between"; break;
case " quelli del":  				$messaggio = " one of those from floor"; break;
case "</b> piano":  				$messaggio = "</b>"; break;
case "della casa":  				$messaggio = "of house"; break;
case "quelli della casa":  			$messaggio = "one of those from house"; break;
case "con massimo numero di occupanti":  	$messaggio = "with maximum number of hosted people"; break;
case "quelli con massimo numero di occupanti":	$messaggio = "one of those with maximum number of hosted people"; break;
case "Non ci sono appartamenti con le <font color=\"red\">caratteristiche</font> richieste":	$messaggio = "There are no apartments with the <font color=\"red\">requested features</font>"; break;
case "a":  					$messaggio = "to"; break;
case "Il numero delle persone verr cambiato da":	$messaggio = "The number of people will be changed from"; break;
case "<b>Non</b> c' nessun appartamento tra quelli richiesti che possa ospitare":	$messaggio = "There is <b>no</b> apartment between the requested ones that can host"; break;
case "persone":  				$messaggio = "people"; break;
case " stata <b>cancellata</b>":  		$messaggio = "has been <b>deleted</b>"; break;
case "Nel periodo selezionato <b>non</b>  possibile ospitare il cliente in un <font color=\"red\">solo appartamento</font> tra quelli richiesti":	$messaggio = "In the selected period it's <b>not</b> possible to host the client always in only <font color=\"red\">one apartment</font> between the requested ones"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = "Movements that must be done in the periods of the <font color=\"blue\">assignation rule 1</font>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "verr spostata dall'appartamento":  	$messaggio = "will be moved from apartment"; break;
case "La prenotazione verr":  			$messaggio = "The reservation will be"; break;
case "mantenuta":  				$messaggio = "left"; break;
case "spostata":  				$messaggio = "moved"; break;
case "nell'appartamento":  			$messaggio = "in apartment"; break;
case "La tariffa":  				$messaggio = "The fare"; break;
case "non esiste pi, cambiala prima di aggiornare":	$messaggio = "doesn't exist anymore, change it before updating"; break;
case "<b>Non</b>  stato ancora inserito il prezzo della":	$messaggio = "You must <b>still</b> insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "La tariffa verr cambiata da":  		$messaggio = "The fare will be changed from"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "non pu essere moltiplicato per":  	$messaggio = "can't be multiplied by"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "The single extra cost"; break;
case "verr moltiplicato per":  		$messaggio = "will be multiplied by"; break;
case "prima era":  				$messaggio = "it was"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "The weeks of the extra cost"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "The days of the extra cost"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>exceed</b> the duration of the reservation"; break;
case "verranno cabiate da":  			$messaggio = "will be changed from"; break;
case "Il costo aggiuntivo settimanale":		$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "will <b>not</b> be changed"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "will <b>not</b> be changed"; break;
case "su":  					$messaggio = "on"; break;
case "Il costo aggiuntivo percentuale":  	$messaggio = "The percentage extra cost"; break;
case "verr tolto":  				$messaggio = "will be deleted"; break;
case "I dati dati del costo aggiuntivo <b>straordinario</b> sono <font color=\"red\">errati o mancanti</font>":	$messaggio = "Data for the <b>extraordinary</b> extra cost are <font color=\"red\">wrong or lacking</font>"; break;
case "verr aggiunto":  			$messaggio = "will be added"; break;
case "come letto aggiuntivo":  			$messaggio = "as extra bed"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "The weeks of the new extra cost"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "The days of the new extra cost"; break;
case "Lo <font color=\"red\">sconto</font> inserito":	$messaggio = "The inserted <font color=\"red\">discount</font>"; break;
case "supera il costo totale senza sconto":  	$messaggio = "is bigger than the complete cost without discount"; break;
case "Lo sconto verr cambiato da":  		$messaggio = "The discount will be changed from"; break;
case "La <font color=\"red\">caparra</font> inserita":	$messaggio = "The inserted <font color=\"red\">deposit</font>"; break;
case "supera il costo totale":  		$messaggio = "is bigger than the complete cost"; break;
case "La caparra verr cambiata da":  		$messaggio = "The deposit will be changed from"; break;
case "La <font color=\"red\">caparra</font>":  	$messaggio = "The <font color=\"red\">deposit</font>"; break;
case "supera il nuovo costo totale":  		$messaggio = "is bigger than the new complete cost"; break;
case "La cifra <font color=\"red\">pagata</font> inserita":	$messaggio = "The inserted <font color=\"red\">paid</font> amount"; break;
case "Gli":  					$messaggio = "The paid"; break;
case "pagati verranno cambiati da":  		$messaggio = "will be changed from"; break;
case "verr <b>confermata</b>":  			$messaggio = "will be <b>confirmed</b>"; break;
case "Verr tolta la <b>conferma</b> alla prenotazione":	$messaggio = "The <b>confirmation</b> will be removed from reservation"; break;
case "Il <b>commento</b> verr cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>commento</b> verr cancellato":  	$messaggio = "The <b>comment</b> will be deleted"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "modificata":  				$messaggio = "modified"; break;
case "<b>non  stata modificata</b> perch la tabella prenotazioni  cambiata nel frattempo":	$messaggio = "<b>has not been modified</b> because the reservations table has changed meanwhile"; break;
case "verr cambiato da":  			$messaggio = "will be changed from"; break;
case "con costo agg.":  			$messaggio = "with extra cost"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.4.3.tar.gz: php-residence/includes/lang/en/modifica_prenota.php <==
<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Modify or delete reservation"; break;
case "Prenotazione a nome di":  		$messaggio = "Reservation for"; break;
case "nato il":  				$messaggio = "born the"; break;
case "nata il":  				$messaggio = "born the"; break;
case "e":  					$messaggio = "and"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "2 telefono":  				$messaggio = "2nd telephone"; break;
case "3 telefono":  				$messaggio = "3rd telephone"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify client's data"; break;
case "La prenotazione  dell'anno precedente, si potr modificare solo la data finale":	$messaggio = "The reservation is from previus year, you will be able to modify only the final date"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "cambia in":  				$messaggio = "change to"; break;
case "Appartamento":  				$messaggio = "Apartment"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "mobile":  				$messaggio = "mobile"; break;
case "in":  					$messaggio = "in"; break;
case "Cambia metodo per l'assegnazione dell'appartamento":	$messaggio = "Change the method for the apartment assignation"; break;
case "N fisso di appartamento":  		$messaggio = "Fixed apartment No"; break;
case "Mobile in tutti gli appartamenti":  	$messaggio = "Mobile in all the apartments"; break;
case "Lista di appartamenti":  			$messaggio = "Apartments list"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "N di piano":  				$messaggio = "Floor number"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "N di persone":  				$messaggio = "Number of people"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Cancella il commento":  			$messaggio = "Delete comment"; break;
case "Tipo di tariffa":  			$messaggio = "Fare type"; break;
case "riassegna l'appartamento con la regola 2":	$messaggio = "reassign the apartment with rule 2"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Sconto":  				$messaggio = "Discount"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "resto":  					$messaggio = "rest"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Calculate again the deposit from the new fare"; break;
case "Costo aggiuntivo finale":  		$messaggio = "Single extra cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Weekly extra cost"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Daily extra cost"; break;
case "per":  					$messaggio = "for"; break;
case "settimane moltiplicato per":  		$messaggio = "weeks multiplied by"; break;
case "giorni moltiplicato per":  		$messaggio = "days multiplied by"; break;
case "Costo aggiuntivo percentuale":  		$messaggio = "Percentage extra cost"; break;
case "della tariffa moltiplicato per":  	$messaggio = "of the fare multiplied by"; break;
case "Prenotazione confermata":  		$messaggio = "Reservation confirmed"; break;
case "Totale da pagare":  			$messaggio = "Total to be paid"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "pagato tutto":  				$messaggio = "all paid"; break;
case "caparra ":  				$messaggio = "deposit paid"; break;
case "Ancora da pagare":  			$messaggio = "Still to be paid"; break;
case "Nuovo costo aggiuntivo finale":  		$messaggio = "New single extra cost"; break;
case "di":  					$messaggio = "of"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "letto":  					$messaggio = "bed"; break;
case "straordinario":  				$messaggio = "extraordinary"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "New weekly extra cost"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "New daily extra cost"; break;
case "n di settimane da applicare":  		$messaggio = "number of weeks to apply"; break;
case "n di giorni da applicare":  		$messaggio = "number of days to apply"; break;
case "Nuovo costo aggiuntivo percentuale":  	$messaggio = "New percentage extra cost"; break;
case "non specificato":  			$messaggio = "not available"; break;
case "Modifica la prenotazione":  		$messaggio = "Modify reservation"; break;
case "Cancella la prenotazione":  		$messaggio = "Delete reservation"; break;
case "Visualizza il contratto":  		$messaggio = "View contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "SI":  					$messaggio = "YES"; break;
case "cancella anche ci che era stato pagato":	$messaggio = "delete also what was paid"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  			$messaggio = "Reservation"; break;
case "era gi stata cancellata":  		$messaggio = "has already been deleted"; break;
case "Prenotazione":  				$messaggio = "Reservation"; break;
case "cancellata":  				$messaggio = "deleted"; break;
case "<b>non  stata cancellata</b> perch  stata modificata nel frattempo":	$messaggio = "<b>has not been deleted</b> because has been modified meanwhile"; break;
case "Si  sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Are you sure you want to <b>delete</b> reservation"; break;
case "La data iniziale verr cambiata dal":  	$messaggio = "The beginning date will be changed from"; break;
case "al":  					$messaggio = "to"; break;
case "La data finale verr cambiata dal":  	$messaggio = "The final date will be changed from"; break;
case "Le <font color=\"red\">date</font> sono <b>sbagliate</b>":	$messaggio = "The <font color=\"red\">dates</font> are <b>wrong</b>"; break;
case "La prenotazione verr spostata dall'appartamento":	$messaggio = "The reservation will be moved from apartment"; break;
case "L'assegnazione dell'appartamento verr cambiata dal":	$messaggio = "The apartment assignation will be changed from"; break;
case "ad uno tra":  				$messaggio = "to an apartment between"; break;
case " quelli del":  				$messaggio = " one of those from floor"; break;
case "</b> piano":  				$messaggio = "</b>"; break;
case "della casa":  				$messaggio = "of house"; break;
case "quelli della casa":  			$messaggio = "one of those from house"; break;
case "con massimo numero di occupanti":  	$messaggio = "with maximum number of hosted people"; break;
case "quelli con massimo numero di occupanti":	$messaggio = "one of those with maximum number of hosted people"; break;
case "Non ci sono appartamenti con le <font color=\"red\">caratteristiche</font> richieste":	$messaggio = "There are no apartments with the <font color=\"red\">requested features</font>"; break;
case "a":  					$messaggio = "to"; break;
case "Il numero delle persone verr cambiato da":	$messaggio = "The number of people will be changed from"; break;
case "<b>Non</b> c' nessun appartamento tra quelli richiesti che possa ospitare":	$messaggio = "There is <b>no</b> apartment between the requested ones that can host"; break;
case "persone":  				$messaggio = "people"; break;
case " stata <b>cancellata</b>":  		$messaggio = "has been <b>deleted</b>"; break;
case "Nel periodo selezionato <b>non</b>  possibile ospitare il cliente in un <font color=\"red\">solo appartamento</font> tra quelli richiesti":	$messaggio = "In the selected period it's <b>not</b> possible to host the client always in only <font color=\"red\">one apartment</font> between the requested ones"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = "Movements that must be done in the periods of the <font color=\"blue\">assignation rule 1</font>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "verr spostata dall'appartamento":  	$messaggio = "will be moved from apartment"; break;
case "La prenotazione verr":  			$messaggio = "The reservation will be"; break;
case "mantenuta":  				$messaggio = "left"; break;
case "spostata":  				$messaggio = "moved"; break;
case "nell'appartamento":  			$messaggio = "in apartment"; break;
case "La tariffa":  				$messaggio = "The fare"; break;
case "non esiste pi, cambiala prima di aggiornare":	$messaggio = "doesn't exist anymore, change it before updating"; break;
case "<b>Non</b>  stato ancora inserito il prezzo della":	$messaggio = "You must <b>still</b> insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "La tariffa verr cambiata da":  		$messaggio = "The fare will be changed from"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "non pu essere moltiplicato per":  	$messaggio = "can't be multiplied by"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "The single extra cost"; break;
case "verr moltiplicato per":  		$messaggio = "will be multiplied by"; break;
case "prima era":  				$messaggio = "it was"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "The weeks of the extra cost"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "The days of the extra cost"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>exceed</b> the duration of the reservation"; break;
case "verranno cabiate da":  			$messaggio = "will be changed from"; break;
case "Il costo aggiuntivo settimanale":		$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "will <b>not</b> be changed"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "will <b>not</b> be changed"; break;
case "su":  					$messaggio = "on"; break;
case "Il costo aggiuntivo percentuale":  	$messaggio = "The percentage extra cost"; break;
case "verr tolto":  				$messaggio = "will be deleted"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <font color=\"red\">errati o mancanti</font>":	$messaggio = "Data for the <b>extraordinary</b> extra cost are <font color=\"red\">wrong or lacking</font>"; break;
case "verr aggiunto":  			$messaggio = "will be added"; break;
case "come letto aggiuntivo":  			$messaggio = "as extra bed"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "The weeks of the new extra cost"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "The days of the new extra cost"; break;
case "Lo <font color=\"red\">sconto</font> inserito":	$messaggio = "The inserted <font color=\"red\">discount</font>"; break;
case "supera il costo totale senza sconto":  	$messaggio = "is bigger than the complete cost without discount"; break;
case "Lo sconto verr cambiato da":  		$messaggio = "The discount will be changed from"; break;
case "La <font color=\"red\">caparra</font> inserita":	$messaggio = "The inserted <font color=\"red\">deposit</font>"; break;
case "supera il costo totale":  		$messaggio = "is bigger than the complete cost"; break;
case "La caparra verr cambiata da":  		$messaggio = "The deposit will be changed from"; break;
case "La <font color=\"red\">caparra</font>":  	$messaggio = "The <font color=\"red\">deposit</font>"; break;
case "supera il nuovo costo totale":  		$messaggio = "is bigger than the new complete cost"; break;
case "La cifra <font color=\"red\">pagata</font> inserita":	$messaggio = "The inserted <font color=\"red\">paid</font> amount"; break;
case "Gli":  					$messaggio = "The paid"; break;
case "pagati verranno cambiati da":  		$messaggio = "will be changed from"; break;
case "verr <b>confermata</b>":  			$messaggio = "will be <b>confirmed</b>"; break;
case "Verr tolta la <b>conferma</b> alla prenotazione":	$messaggio = "The <b>confirmation</b> will be removed from reservation"; break;
case "Il <b>commento</b> verr cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>commento</b> verr cancellato":  	$messaggio = "The <b>comment</b> will be deleted"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "modificata":  				$messaggio = "modified"; break;
case "<b>non  stata modificata</b> perch la tabella prenotazioni  cambiata nel frattempo":	$messaggio = "<b>has not been modified</b> because the reservations table has changed meanwhile"; break;
case "verr cambiato da":  			$messaggio = "will be changed from"; break;
case "con costo agg.":  			$messaggio = "with extra cost"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "Non c' nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignation rule 1 in which is allowed to insert reservations for user"; break;
case "Non c' nessun appartamento tra quelli richiesti in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no apartments between the requested ones in which is allowed to insert reservations for user"; break;
case "L'appartamento":  			$messaggio = "The apartment"; break;
case "contenuto nella lista non esiste":  	$messaggio = "included in the list does not exist"; break;
case "Prenotazione non confermata":  		$messaggio = "Reservation not confirmed"; break;
case "Sposta nell'appartamento":  		$messaggio = "Move in apartment"; break;
case "Inserita dall'utente":  			$messaggio = "Inserted by user"; break;
case "Si considerer l'utente":  		$messaggio = "User"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "will be considered as the one who inserted the reservation"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
